@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -233,6 +229,7 @@ public class CurrencyNames_hu extends OpenListResourceBundle {
             { "aed", "EAE-dirham" },
             { "afa", "afg\u00e1n afghani (1927\u20132002)" },
             { "afn", "afg\u00e1n afghani" },
+            { "alk", "alb\u00e1n lek (1946\u20131965)" },
             { "all", "alb\u00e1n lek" },
             { "amd", "\u00f6rm\u00e9ny dram" },
             { "ang", "holland antill\u00e1ki forint" },
@@ -250,13 +247,16 @@ public class CurrencyNames_hu extends OpenListResourceBundle {
             { "azn", "azerbajdzs\u00e1ni manat" },
             { "bad", "Bosznia-hercegovinai d\u00edn\u00e1r (1992\u20131994)" },
             { "bam", "bosznia-hercegovinai konvertibilis m\u00e1rka" },
+            { "ban", "bosznia-hercegovinai \u00faj d\u00edn\u00e1r (1994\u20131997)" },
             { "bbd", "barbadosi doll\u00e1r" },
             { "bdt", "bangladesi taka" },
             { "bec", "Belga frank (konvertibilis)" },
             { "bef", "Belga frank" },
             { "bel", "Belga frank (p\u00e9nz\u00fcgyi)" },
             { "bgl", "Bolg\u00e1r kem\u00e9ny leva" },
+            { "bgm", "bolg\u00e1r szocialista leva" },
             { "bgn", "bolg\u00e1r \u00faj leva" },
+            { "bgo", "bolg\u00e1r leva (1879\u20131952)" },
             { "bhd", "bahreini din\u00e1r" },
             { "bif", "burundi frank" },
             { "bmd", "bermudai doll\u00e1r" },
@@ -294,7 +294,7 @@ public class CurrencyNames_hu extends OpenListResourceBundle {
             { "csk", "Csehszlov\u00e1k kem\u00e9ny korona" },
             { "cuc", "kubai konvertibilis peso" },
             { "cup", "kubai peso" },
-            { "cve", "Cape Verde-i escudo" },
+            { "cve", "Z\u00f6ld-foki escudo" },
             { "cyp", "Ciprusi font" },
             { "czk", "cseh korona" },
             { "ddm", "Kelet-N\u00e9met m\u00e1rka" },
@@ -374,10 +374,12 @@ public class CurrencyNames_hu extends OpenListResourceBundle {
             { "lyd", "l\u00edbiai d\u00edn\u00e1r" },
             { "mad", "marokk\u00f3i dirham" },
             { "maf", "Marokk\u00f3i frank" },
+            { "mdc", "mold\u00e1v kupon" },
             { "mdl", "moldov\u00e1n lei" },
             { "mga", "madagaszk\u00e1ri ariary" },
             { "mgf", "Madagaszk\u00e1ri frank" },
             { "mkd", "macedon d\u00edn\u00e1r" },
+            { "mkn", "maced\u00f3n d\u00e9n\u00e1r (1992\u20131993)" },
             { "mlf", "Mali frank" },
             { "mmk", "mianmari kyat" },
             { "mnt", "mong\u00f3liai tugrik" },
@@ -501,6 +503,7 @@ public class CurrencyNames_hu extends OpenListResourceBundle {
             { "yud", "Jugoszl\u00e1v kem\u00e9ny d\u00edn\u00e1r" },
             { "yum", "Jugoszl\u00e1v \u00faj d\u00edn\u00e1r" },
             { "yun", "Jugoszl\u00e1v konvertibilis d\u00edn\u00e1r" },
+            { "yur", "jugoszl\u00e1v reform\u00e1lt din\u00e1r (1992\u20131993)" },
             { "zal", "D\u00e9l-afrikai rand (p\u00e9nz\u00fcgyi)" },
             { "zar", "d\u00e9l-afrikai rand" },
             { "zmk", "Zambiai kwacha (1968\u20132012)" },
