@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -75,6 +71,7 @@ public class LocaleNames_iw extends OpenListResourceBundle {
         final String metaValue_ml = "\u05de\u05dc\u05d9\u05d0\u05dc\u05d0\u05dd";
         final String metaValue_si = "\u05e1\u05d9\u05e0\u05d4\u05dc\u05d4";
         final String metaValue_te = "\u05d8\u05dc\u05d5\u05d2\u05d5";
+        final String metaValue_nqo = "\u05e0\u05f3\u05e7\u05d5";
         final Object[][] data = new Object[][] {
             { "ksh", "\u05e7\u05d5\u05dc\u05d5\u05e0\u05d9\u05d0\u05df" },
             { "mwl", "\u05de\u05d9\u05e8\u05e0\u05d3\u05d6\u05d9\u05ea" },
@@ -180,6 +177,7 @@ public class LocaleNames_iw extends OpenListResourceBundle {
             { "DO", "\u05d4\u05e8\u05e4\u05d5\u05d1\u05dc\u05d9\u05e7\u05d4 \u05d4\u05d3\u05d5\u05de\u05d9\u05e0\u05d9\u05e7\u05e0\u05d9\u05ea" },
             { "gor", "\u05d2\u05d5\u05e8\u05d5\u05e0\u05d8\u05d0\u05dc\u05d5" },
             { "got", "\u05d2\u05d5\u05ea\u05d9\u05ea" },
+            { "Mtei", "\u05de\u05d0\u05d9\u05d8\u05d9 \u05de\u05d0\u05d9\u05d9\u05e7" },
             { "zun", "\u05d6\u05d5\u05e0\u05d9" },
             { "tig", "\u05d8\u05d9\u05d2\u05e8\u05d9\u05ea" },
             { "DZ", "\u05d0\u05dc\u05d2\u05f3\u05d9\u05e8\u05d9\u05d4" },
@@ -260,7 +258,7 @@ public class LocaleNames_iw extends OpenListResourceBundle {
             { "HN", "\u05d4\u05d5\u05e0\u05d3\u05d5\u05e8\u05e1" },
             { "HR", "\u05e7\u05e8\u05d5\u05d0\u05d8\u05d9\u05d4" },
             { "agq", "\u05d0\u05e2\u05f3\u05dd" },
-            { "gsw", "\u05d2\u05e8\u05de\u05e0\u05d9\u05ea (\u05d1\u05e9\u05d5\u05d5\u05d9\u05e5)" },
+            { "gsw", "\u05d2\u05e8\u05de\u05e0\u05d9\u05ea \u05e9\u05d5\u05d5\u05d9\u05e6\u05e8\u05d9\u05ea" },
             { "type.ca.islamic-umalqura", "\u05dc\u05d5\u05d7 \u05d4\u05e9\u05e0\u05d4 \u05d4\u05de\u05d5\u05e1\u05dc\u05de\u05d9 \u05d0\u05d5\u05dd \u05d0\u05dc-\u05e7\u05d5\u05e8\u05d0" },
             { "HT", "\u05d4\u05d0\u05d9\u05d8\u05d9" },
             { "HU", "\u05d4\u05d5\u05e0\u05d2\u05e8\u05d9\u05d4" },
@@ -483,6 +481,7 @@ public class LocaleNames_iw extends OpenListResourceBundle {
             { "TC", "\u05d0\u05d9\u05d9 \u05d8\u05e8\u05e7\u05e1 \u05d5\u05e7\u05d9\u05d9\u05e7\u05d5\u05e1" },
             { "yav", "\u05d9\u05d0\u05e0\u05d2\u05d1\u05df" },
             { "TD", "\u05e6\u05f3\u05d0\u05d3" },
+            { "Qaag", "\u05d6\u05d0\u05d5\u05d2\u05d9\u05d9" },
             { "TF", "\u05d4\u05d8\u05e8\u05d9\u05d8\u05d5\u05e8\u05d9\u05d5\u05ea \u05d4\u05d3\u05e8\u05d5\u05de\u05d9\u05d5\u05ea \u05e9\u05dc \u05e6\u05e8\u05e4\u05ea" },
             { "TG", "\u05d8\u05d5\u05d2\u05d5" },
             { "TH", "\u05ea\u05d0\u05d9\u05dc\u05e0\u05d3" },
@@ -560,9 +559,10 @@ public class LocaleNames_iw extends OpenListResourceBundle {
             { "XK", "\u05e7\u05d5\u05e1\u05d5\u05d1\u05d5" },
             { "Gujr", "\u05d2\u05d5\u05d2\u05f3\u05e8\u05d8\u05d9" },
             { "Zxxx", "\u05dc\u05d0 \u05db\u05ea\u05d5\u05d1" },
+            { "Olck", "\u05d0\u05d5\u05dc \u05e6\u05f3\u05d9\u05e7\u05d9" },
             { "wbp", "\u05d5\u05d5\u05e8\u05dc\u05e4\u05d9\u05e8\u05d9" },
             { "YE", "\u05ea\u05d9\u05de\u05df" },
-            { "nqo", "\u05e0\u05f3\u05e7\u05d5" },
+            { "nqo", metaValue_nqo },
             { "type.co.standard", "\u05e1\u05d3\u05e8 \u05de\u05d9\u05d5\u05df \u05e8\u05d2\u05d9\u05dc" },
             { "fan", "\u05e4\u05e0\u05d2" },
             { "fat", "\u05e4\u05d0\u05e0\u05d8\u05d9" },
@@ -640,6 +640,7 @@ public class LocaleNames_iw extends OpenListResourceBundle {
             { "scn", "\u05e1\u05d9\u05e6\u05d9\u05dc\u05d9\u05d0\u05e0\u05d9\u05ea" },
             { "aa", "\u05d0\u05e4\u05d0\u05e8\u05d9\u05ea" },
             { "ab", "\u05d0\u05d1\u05d7\u05d6\u05d9\u05ea" },
+            { "Aran", "\u05e0\u05e1\u05ea\u05e2\u05dc\u05d9\u05e7" },
             { "ae", "\u05d0\u05d1\u05e1\u05d8\u05df" },
             { "af", "\u05d0\u05e4\u05e8\u05d9\u05e7\u05d0\u05e0\u05e1" },
             { "ak", "\u05d0\u05e7\u05d0\u05df" },
@@ -670,6 +671,7 @@ public class LocaleNames_iw extends OpenListResourceBundle {
             { "Mymr", "\u05de\u05d9\u05d0\u05e0\u05de\u05e8" },
             { "type.nu.laoo", "\u05e1\u05e4\u05e8\u05d5\u05ea \u05e9\u05dc \u05dc\u05d0\u05d5\u05e1" },
             { "seh", "\u05e1\u05e0\u05d4" },
+            { "Nkoo", metaValue_nqo },
             { "sel", "\u05e1\u05dc\u05e7\u05d5\u05e4" },
             { "ca", "\u05e7\u05d8\u05dc\u05d0\u05e0\u05d9\u05ea" },
             { "ses", "\u05e7\u05d5\u05d9\u05e8\u05d0\u05d1\u05d5\u05e8\u05d5 \u05e1\u05e0\u05d9" },
@@ -835,6 +837,7 @@ public class LocaleNames_iw extends OpenListResourceBundle {
             { "mdf", "\u05de\u05d5\u05e7\u05e9\u05d4" },
             { "mde", "\u05de\u05d0\u05d1\u05d0" },
             { "dsb", "\u05e1\u05d5\u05e8\u05d1\u05d9\u05ea \u05ea\u05d7\u05ea\u05d9\u05ea" },
+            { "Armi", "\u05d0\u05e8\u05de\u05d9\u05ea \u05e8\u05e9\u05de\u05d9\u05ea" },
             { "na", "\u05e0\u05d0\u05d5\u05e8\u05d9\u05ea" },
             { "type.co.search", "\u05d7\u05d9\u05e4\u05d5\u05e9 \u05dc\u05de\u05d8\u05e8\u05d4 \u05db\u05dc\u05dc\u05d9\u05ea" },
             { "nb", "\u05e0\u05d5\u05e8\u05d5\u05d5\u05d2\u05d9\u05ea \u05e1\u05e4\u05e8\u05d5\u05ea\u05d9\u05ea" },
@@ -1063,6 +1066,7 @@ public class LocaleNames_iw extends OpenListResourceBundle {
             { "type.nu.tamldec", "\u05e1\u05e4\u05e8\u05d5\u05ea \u05d8\u05de\u05d9\u05dc\u05d9\u05d5\u05ea" },
             { "krc", "\u05e7\u05e8\u05d0\u05e6\u05f3\u05d9-\u05d1\u05dc\u05e7\u05e8" },
             { "inh", "\u05d0\u05d9\u05e0\u05d2\u05d5\u05e9\u05d9\u05ea" },
+            { "fa_AF", "\u05d3\u05d0\u05e8\u05d9" },
             { "krl", "\u05e7\u05d0\u05e8\u05dc\u05d9\u05ea" },
             { "efi", "\u05d0\u05e4\u05d9\u05e7" },
             { "key.nu", "\u05de\u05e1\u05e4\u05e8\u05d9\u05dd" },
