@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2018, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -142,12 +138,12 @@ public class LocaleNames_mt extends OpenListResourceBundle {
             { "CD", "ir-Repubblika Demokratika tal-Kongo" },
             { "CF", "ir-Repubblika \u010aentru-Afrikana" },
             { "CG", "il-Kongo - Brazzaville" },
-            { "CH", "\u017bvizzera" },
+            { "CH", "l-I\u017cvizzera" },
             { "CI", "il-Kosta tal-Avorju" },
             { "CK", "G\u017cejjer Cook" },
             { "CL", "i\u010b-\u010aili" },
             { "CM", "il-Kamerun" },
-            { "CN", "CN" },
+            { "CN", "i\u010b-\u010aina" },
             { "CO", "il-Kolombja" },
             { "CP", "il-G\u017cira Clipperton" },
             { "CR", "il-Costa Rica" },
@@ -319,7 +315,7 @@ public class LocaleNames_mt extends OpenListResourceBundle {
             { "MG", "Madagascar" },
             { "MH", "G\u017cejjer Marshall" },
             { "ale", "Aleut" },
-            { "MK", "l-Eks-Repubblika Jugoslava tal-Ma\u010bedonia" },
+            { "MK", "il-Ma\u010bedonja ta\u2019 Fuq" },
             { "ML", "il-Mali" },
             { "MM", "il-Myanmar/Burma" },
             { "MN", "il-Mongolja" },
@@ -501,7 +497,7 @@ public class LocaleNames_mt extends OpenListResourceBundle {
             { "war", "Waray" },
             { "awa", "Awadhi" },
             { "061", "Polinesja" },
-            { "XK", "Kosovo" },
+            { "XK", "il-Kosovo" },
             { "Zxxx", "Mhux Miktub" },
             { "YE", "il-Jemen" },
             { "nqo", "N\u2019Ko" },
