@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2018, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -87,6 +83,8 @@ public class LocaleNames_nb extends OpenListResourceBundle {
         final String metaValue_ml = "malayalam";
         final String metaValue_mn = "mongolsk";
         final String metaValue_my = "burmesisk";
+        final String metaValue_or = "odia";
+        final String metaValue_si = "singalesisk";
         final String metaValue_su = "sundanesisk";
         final String metaValue_te = "telugu";
         final String metaValue_th = "thai";
@@ -94,6 +92,7 @@ public class LocaleNames_nb extends OpenListResourceBundle {
         final String metaValue_arc = "arameisk";
         final String metaValue_ban = "balinesisk";
         final String metaValue_bug = "buginesisk";
+        final String metaValue_ccp = "chakma";
         final String metaValue_cop = "koptisk";
         final String metaValue_got = "gotisk";
         final String metaValue_kpe = "kpelle";
@@ -119,6 +118,7 @@ public class LocaleNames_nb extends OpenListResourceBundle {
             { "Zsye", "emoji" },
             { "%%NJIVA", "gniva- og njivadialekt" },
             { "xmf", "mingrelsk" },
+            { "ccp", metaValue_ccp },
             { "egy", "gammelegyptisk" },
             { "raj", "rajasthani" },
             { "Phag", "phags-pa" },
@@ -187,7 +187,7 @@ public class LocaleNames_nb extends OpenListResourceBundle {
             { "CA", "Canada" },
             { "CC", "Kokos\u00f8yene" },
             { "mzn", "mazandarani" },
-            { "CD", "Kongo-Kinshasa" },
+            { "CD", "Kongo" },
             { "CF", "Den sentralafrikanske republikk" },
             { "CG", "Kongo-Brazzaville" },
             { "CH", "Sveits" },
@@ -260,7 +260,7 @@ public class LocaleNames_nb extends OpenListResourceBundle {
             { "ER", "Eritrea" },
             { "ES", "Spania" },
             { "ET", "Etiopia" },
-            { "EU", "EU" },
+            { "EU", "Den europeiske union" },
             { "elx", "elamittisk" },
             { "type.ca.gregorian", "gregoriansk kalender" },
             { "EZ", "eurosonen" },
@@ -273,7 +273,7 @@ public class LocaleNames_nb extends OpenListResourceBundle {
             { "FJ", "Fiji" },
             { "FK", "Falklands\u00f8yene" },
             { "FM", "Mikronesiaf\u00f8derasjonen" },
-            { "key.va", "Spr\u00e5kvariant" },
+            { "key.va", "spr\u00e5kvariant" },
             { "FO", "F\u00e6r\u00f8yene" },
             { "Taml", "tamilsk" },
             { "FR", "Frankrike" },
@@ -321,7 +321,7 @@ public class LocaleNames_nb extends OpenListResourceBundle {
             { "tly", "talysj" },
             { "pdt", "plautdietsch" },
             { "Vaii", metaValue_vai },
-            { "HK", "Hongkong S.A.R. Kina" },
+            { "HK", "Hongkong SAR Kina" },
             { "HM", "Heard- og McDonald\u00f8yene" },
             { "HN", "Honduras" },
             { "HR", "Kroatia" },
@@ -404,7 +404,6 @@ public class LocaleNames_nb extends OpenListResourceBundle {
             { "LC", "St. Lucia" },
             { "Cyrs", "kirkeslavisk kyrillisk" },
             { "gwi", "gwichin" },
-            { "%%LUNA1918", "LUNA1918" },
             { "nds", "nedertysk" },
             { "LI", "Liechtenstein" },
             { "LK", "Sri Lanka" },
@@ -440,12 +439,12 @@ public class LocaleNames_nb extends OpenListResourceBundle {
             { "MH", "Marshall\u00f8yene" },
             { "ale", "aleutisk" },
             { "type.nu.vaii", "vai-sifre" },
-            { "MK", "Makedonia" },
+            { "MK", "Nord-Makedonia" },
             { "ML", "Mali" },
             { "MM", "Myanmar (Burma)" },
             { "MN", "Mongolia" },
             { "new", "newari" },
-            { "MO", "Macao S.A.R. Kina" },
+            { "MO", "Macao SAR Kina" },
             { "aln", "gegisk-albansk" },
             { "MP", "Nord-Marianene" },
             { "MQ", "Martinique" },
@@ -494,7 +493,6 @@ public class LocaleNames_nb extends OpenListResourceBundle {
             { "crh", "krimtatarisk" },
             { "ang", "gammelengelsk" },
             { "OM", "Oman" },
-            { "%%PETR1708", "PETR1708" },
             { "anp", "angika" },
             { "crs", "seselwa" },
             { "Xpeo", metaValue_peo },
@@ -510,7 +508,7 @@ public class LocaleNames_nb extends OpenListResourceBundle {
             { "PL", "Polen" },
             { "ewo", "ewondo" },
             { "PM", "Saint-Pierre-et-Miquelon" },
-            { "PN", "Pitcairn" },
+            { "PN", "Pitcairn\u00f8yene" },
             { "PR", "Puerto Rico" },
             { "Bali", metaValue_ban },
             { "PS", "Det palestinske omr\u00e5det" },
@@ -547,20 +545,11 @@ public class LocaleNames_nb extends OpenListResourceBundle {
             { "009", "Oseania" },
             { "%%SURSILV", "sursilvan" },
             { "RO", "Romania" },
-            { "Qaaw", "qaaw" },
             { "RS", "Serbia" },
             { "Mroo", "mro" },
-            { "Qaax", "qaax" },
-            { "Qaau", "qaau" },
             { "RU", "Russland" },
-            { "Qaav", "qaav" },
-            { "Qaas", "qaas" },
             { "RW", "Rwanda" },
-            { "Qaat", "qaat" },
-            { "Qaaq", "qaaq" },
-            { "Qaar", "qaar" },
             { "type.nu.talu", "ny tai lue-tall" },
-            { "Qaba", "qaba" },
             { "%%METELKO", "Metelko-alfabet" },
             { "Ugar", metaValue_uga },
             { "Mani", "manikeisk" },
@@ -568,55 +557,37 @@ public class LocaleNames_nb extends OpenListResourceBundle {
             { "SA", "Saudi-Arabia" },
             { "pon", "ponapisk" },
             { "Mand", "mandaisk" },
-            { "Qaay", "qaay" },
             { "SB", "Salomon\u00f8yene" },
             { "twq", "tasawaq" },
-            { "Qaaz", "qaaz" },
             { "011", "Vest-Afrika" },
             { "SC", "Seychellene" },
-            { "Qabh", "qabh" },
             { "SD", "Sudan" },
-            { "Qabi", "qabi" },
             { "013", "Mellom-Amerika" },
             { "SE", "Sverige" },
-            { "Qabf", "qafb" },
             { "arc", metaValue_arc },
             { "014", "\u00d8st-Afrika" },
             { "Loma", "loma" },
-            { "Qabg", "qabg" },
             { "015", "Nord-Afrika" },
             { "SG", "Singapore" },
-            { "Qabd", "qabd" },
             { "SH", "St. Helena" },
-            { "Qabe", "qabe" },
             { "type.lb.strict", "streng linjeskiftstil" },
             { "017", "Sentral-Afrika" },
             { "SI", "Slovenia" },
-            { "Qabb", "qabb" },
             { "018", "S\u00f8rlige Afrika" },
             { "SJ", "Svalbard og Jan Mayen" },
-            { "Qabc", "qabc" },
             { "019", "Amerika" },
             { "SK", "Slovakia" },
             { "Bamu", "bamum" },
-            { "Qabp", "qabp" },
             { "Wole", "woleai" },
             { "SL", "Sierra Leone" },
-            { "Qabq", "qabq" },
             { "SM", "San Marino" },
-            { "Qabn", "qabn" },
             { "SN", "Senegal" },
-            { "Qabo", "qabo" },
             { "SO", "Somalia" },
             { "arn", "mapudungun" },
-            { "Qabl", "qabl" },
-            { "Qabm", "qabm" },
             { "arp", "arapaho" },
-            { "Qabj", "qabj" },
             { "type.nu.taml", "tamilske tall" },
             { "SR", "Surinam" },
             { "aro", "araona" },
-            { "Qabk", "qabk" },
             { "SS", "S\u00f8r-Sudan" },
             { "ST", "S\u00e3o Tom\u00e9 og Pr\u00edncipe" },
             { "arq", "algerisk arabisk" },
@@ -625,7 +596,7 @@ public class LocaleNames_nb extends OpenListResourceBundle {
             { "SX", "Sint Maarten" },
             { "SY", "Syria" },
             { "yao", "yao" },
-            { "SZ", "Swaziland" },
+            { "SZ", "Eswatini" },
             { "arw", "arawak" },
             { "arz", "egyptisk arabisk" },
             { "ary", "marokkansk-arabisk" },
@@ -638,35 +609,22 @@ public class LocaleNames_nb extends OpenListResourceBundle {
             { "TC", "Turks- og Caicos\u00f8yene" },
             { "yav", "yangben" },
             { "TD", "Tsjad" },
-            { "Qaag", "qaag" },
-            { "Qaah", "qaah" },
+            { "Qaag", "zawgyi" },
             { "TF", "De franske s\u00f8rterritorier" },
             { "ase", "amerikansk tegnspr\u00e5k" },
-            { "Qaae", "qaae" },
             { "TG", "Togo" },
-            { "Qaaf", "qaaf" },
             { "TH", "Thailand" },
-            { "Qaac", "qaac" },
-            { "Qaad", "qaad" },
             { "TJ", "Tadsjikistan" },
-            { "Qaaa", "qaaa" },
             { "029", "Karibia" },
             { "TK", "Tokelau" },
-            { "Qaab", "qaab" },
             { "TL", "\u00d8st-Timor" },
             { "ybb", "yemba" },
-            { "Qaao", "qaao" },
             { "type.co.searchjl", "S\u00f8k etter f\u00f8rste konsonant i hangul" },
             { "TM", "Turkmenistan" },
-            { "Qaap", "qaap" },
             { "%%BOONT", "boontling" },
             { "TN", "Tunisia" },
-            { "Qaam", "qaam" },
             { "TO", "Tonga" },
-            { "Qaan", "qaan" },
             { "%%NULIK", "moderne volap\u00fck" },
-            { "Qaak", "qaak" },
-            { "Qaal", "qaal" },
             { "TR", "Tyrkia" },
             { "TT", "Trinidad og Tobago" },
             { "TV", "Tuvalu" },
@@ -692,26 +650,19 @@ public class LocaleNames_nb extends OpenListResourceBundle {
             { "hak", "hakka" },
             { "type.co.pinyin", "pinyinsortering" },
             { "039", "S\u00f8r-Europa" },
-            { "Sinh", "sinhala" },
+            { "Sinh", metaValue_si },
             { "UM", "USAs ytre \u00f8yer" },
             { "liv", "livisk" },
             { "UN", "FN" },
             { "US", "USA" },
             { "haw", "hawaiisk" },
-            { "Qabx", "qabx" },
             { "%%1959ACAD", "akademisk" },
-            { "Qabv", "qabv" },
             { "type.co.gb2312han", "forenklet kinesisk sortering - GB2312" },
-            { "Qabw", "qabw" },
             { "UY", "Uruguay" },
             { "prg", "pr\u00f8yssisk" },
-            { "Qabt", "qabt" },
             { "UZ", "Usbekistan" },
-            { "Qabu", "qabu" },
             { "tzm", "sentralmarokkansk tamazight" },
-            { "Qabr", "qabr" },
             { "type.co.stroke", "streksortering" },
-            { "Qabs", "qabs" },
             { "nnh", "ngiemboon" },
             { "VA", "Vatikanstaten" },
             { "pro", "gammelproven\u00e7alsk" },
@@ -743,7 +694,9 @@ public class LocaleNames_nb extends OpenListResourceBundle {
             { "type.nu.mtei", "meetei mayek-tall" },
             { "wal", "wolaytta" },
             { "was", "washo" },
+            { "XA", "pseudospr\u00e5k \u2013 aksenter" },
             { "war", "waray-waray" },
+            { "XB", "pseudospr\u00e5k \u2013 tekst begge veier" },
             { "awa", "avadhi" },
             { "061", "Polynesia" },
             { "%%KSCOR", "standard ortografi" },
@@ -789,7 +742,7 @@ public class LocaleNames_nb extends OpenListResourceBundle {
             { "Nkgb", "naxi geba" },
             { "jmc", "machame" },
             { "hif", "fijiansk hindi" },
-            { "type.nu.hansfin", "forenklede kinesiske finanstall" },
+            { "type.nu.hansfin", "forenklet kinesisk-finanstall" },
             { "hil", "hiligaynon" },
             { "type.nu.arabext", "utvidede arabisk-indiske sifre" },
             { "nus", "nuer" },
@@ -855,6 +808,7 @@ public class LocaleNames_nb extends OpenListResourceBundle {
             { "scn", "siciliansk" },
             { "aa", "afar" },
             { "ab", "abkhasisk" },
+            { "Aran", "nastaliq" },
             { "bbc", "batak toba" },
             { "ae", metaValue_ae },
             { "af", "afrikaans" },
@@ -904,7 +858,7 @@ public class LocaleNames_nb extends OpenListResourceBundle {
             { "ch", "chamorro" },
             { "%%REVISED", "revidert ortografi" },
             { "co", "korsikansk" },
-            { "Orya", "oriya" },
+            { "Orya", metaValue_or },
             { "cr", "cree" },
             { "cs", "tsjekkisk" },
             { "cu", "kirkeslavisk" },
@@ -945,7 +899,7 @@ public class LocaleNames_nb extends OpenListResourceBundle {
             { "type.co.big5han", "tradisjonell kinesisk sortering - Big 5" },
             { "es", "spansk" },
             { "et", "estisk" },
-            { "Hanb", "hanb" },
+            { "Hanb", "han-kinesisk med bopomofo" },
             { "eu", "baskisk" },
             { "Buhd", "buhid" },
             { "Hang", "hangul" },
@@ -1007,7 +961,6 @@ public class LocaleNames_nb extends OpenListResourceBundle {
             { "ig", "ibo" },
             { "ii", "sichuan-yi" },
             { "frm", "mellomfransk" },
-            { "%%RUMGR", "RUMGR" },
             { "ik", "inupiak" },
             { "fro", "gammelfransk" },
             { "frp", "arpitansk" },
@@ -1127,7 +1080,7 @@ public class LocaleNames_nb extends OpenListResourceBundle {
             { "om", "oromo" },
             { "kaw", "kawi" },
             { "dtp", "sentraldusun" },
-            { "or", "odia" },
+            { "or", metaValue_or },
             { "Modi", "modi" },
             { "os", "ossetisk" },
             { "%%ALALC97", "ALA-LC-romanisering, 1997-utgaven" },
@@ -1203,7 +1156,7 @@ public class LocaleNames_nb extends OpenListResourceBundle {
             { "sg", "sango" },
             { "sh", "serbokroatisk" },
             { "ken", "kenyang" },
-            { "si", "singalesisk" },
+            { "si", metaValue_si },
             { "sux", "sumerisk" },
             { "sk", "slovakisk" },
             { "sl", "slovensk" },
@@ -1222,7 +1175,7 @@ public class LocaleNames_nb extends OpenListResourceBundle {
             { "%%NEDIS", "natisonedialekt" },
             { "sv", "svensk" },
             { "sw", "swahili" },
-            { "type.nu.hantfin", "tradisjonelle kinesiske finanstall" },
+            { "type.nu.hantfin", "tradisjonell kinesisk-finanstall" },
             { "ibb", "ibibio" },
             { "iba", "iban" },
             { "ta", "tamil" },
@@ -1244,9 +1197,9 @@ public class LocaleNames_nb extends OpenListResourceBundle {
             { "dyo", "jola-fonyi" },
             { "type.nu.jpan", "japanske tall" },
             { "tr", "tyrkisk" },
+            { "Cakm", metaValue_ccp },
             { "ts", "tsonga" },
             { "swb", "komorisk" },
-            { "Cakm", "chakma" },
             { "tt", "tatarisk" },
             { "dyu", "dyula" },
             { "tw", "twi" },
@@ -1312,8 +1265,8 @@ public class LocaleNames_nb extends OpenListResourceBundle {
             { "mni", "manipuri" },
             { "Latn", "latinsk" },
             { "Latg", "g\u00e6lisk latinsk" },
-            { "type.nu.hans", "forenklede kinesiske tall" },
-            { "type.nu.hant", "tradisjonelle kinesiske tall" },
+            { "type.nu.hans", "forenklet kinesisk-tall" },
+            { "type.nu.hant", "tradisjonell kinesisk-tall" },
             { "xh", "xhosa" },
             { "type.nu.romanlow", "sm\u00e5 romertall" },
             { "byn", "blin" },
@@ -1390,7 +1343,6 @@ public class LocaleNames_nb extends OpenListResourceBundle {
             { "mua", "mundang" },
             { "type.nu.guru", "gurmukhi-sifre" },
             { "mul", "flere spr\u00e5k" },
-            { "%%PUTER", "PUTER" },
             { "cad", "caddo" },
             { "key.ms", "m\u00e5lesystem" },
             { "mus", "creek" },
@@ -1405,6 +1357,7 @@ public class LocaleNames_nb extends OpenListResourceBundle {
             { "inh", "ingusjisk" },
             { "krj", "kinaray-a" },
             { "kri", "krio" },
+            { "fa_AF", "dari" },
             { "krl", "karelsk" },
             { "efi", "efik" },
             { "tcy", "tulu" },
