@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -328,6 +324,7 @@ public class LocaleNames_pcm extends OpenListResourceBundle {
             { "guz", "Gus\u00ed L\u00e1ngwej" },
             { "type.nu.knda", "K\u00e1nn\u00e1d N\u1ecd\u0301mba-d\u1eb9m" },
             { "de_CH", "Sw\u00edtzaland Ha\u00ed J\u00e1m\u00e1n" },
+            { "mai", "Ma\u00edt\u00edli" },
             { "smn", "\u00cdn\u00e1r\u00ed S\u00e1m\u00ed L\u00e1ngwej" },
             { "ka", "J\u1ecd\u0301ji\u00e1 L\u00e1ngwej" },
             { "type.ca.buddhist", "B\u00fad\u00edst Kal\u1eb9\u0301nda" },
@@ -659,6 +656,7 @@ public class LocaleNames_pcm extends OpenListResourceBundle {
             { "WS", "Sam\u00f3a" },
             { "Mong", metaValue_MN },
             { "XA", "To y\u00faz atif\u00edsh\u00e1l v\u1ecdis w\u1eb9\u0301n yu de t\u1ecdk" },
+            { "mni", "Man\u00edpuri" },
             { "XB", "At\u00edf\u00edsh\u00e1l T\u00fa-W\u00e9 Dair\u1eb9\u0301ksh\u1ecdn" },
             { "061", "Polin\u00edshi\u00e1" },
             { "Latn", "L\u00e1tin" },
@@ -717,6 +715,7 @@ public class LocaleNames_pcm extends OpenListResourceBundle {
             { "type.nu.tamldec", "T\u00e1m\u00edl N\u1ecd\u0301mba-d\u1eb9m" },
             { "saq", "Samb\u00faru" },
             { "fa_AF", "D\u00e1ri" },
+            { "sat", "S\u00e1nt\u00e1li" },
             { "key.nu", "N\u1ecd\u0301mba-d\u1eb9m" },
             { "Guru", "G\u00farmukhi" },
             { "ksb", "Shambala" },
