@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -153,8 +149,10 @@ public class LocaleNames_zh extends OpenListResourceBundle {
             { "BZ", "\u4f2f\u5229\u5179" },
             { "Visp", "\u53ef\u89c1\u8bed\u8a00" },
             { "type.ca.persian", "\u6ce2\u65af\u5386" },
+            { "%%CREISS", "\u514b\u96f7\u6851\u65b9\u8a00" },
             { "type.nu.hebr", "\u5e0c\u4f2f\u6765\u6570\u5b57" },
             { "CA", "\u52a0\u62ff\u5927" },
+            { "Kits", "\u5951\u4e39\u5c0f\u5b57" },
             { "CC", "\u79d1\u79d1\u65af\uff08\u57fa\u6797\uff09\u7fa4\u5c9b" },
             { "mzn", "\u9a6c\u8d5e\u5fb7\u5170\u8bed" },
             { "CD", "\u521a\u679c\uff08\u91d1\uff09" },
@@ -178,6 +176,7 @@ public class LocaleNames_zh extends OpenListResourceBundle {
             { "type.nu.bali", "\u5df4\u5398\u6587\u6570\u5b57" },
             { "CZ", "\u6377\u514b" },
             { "eka", "\u827e\u5361\u6731\u514b\u8bed" },
+            { "Ahom", "Ahom" },
             { "Pauc", "\u5305\u91d1\u8c6a\u6587" },
             { "%%RIGIK", "\u53e4\u5178\u6c83\u62c9\u666e\u514b\u8bed" },
             { "Sogd", "\u7c9f\u7279\u6587" },
@@ -283,6 +282,7 @@ public class LocaleNames_zh extends OpenListResourceBundle {
             { "ckb", "\u4e2d\u5e93\u5c14\u5fb7\u8bed" },
             { "zxx", "\u65e0\u8bed\u8a00\u5185\u5bb9" },
             { "Jurc", "\u5973\u771f\u6587" },
+            { "%%VIVARAUP", "\u7ef4\u74e6\u9c81\u666e\u65b9\u8a00" },
             { "de_AT", "\u5965\u5730\u5229\u5fb7\u8bed" },
             { "HK", "\u4e2d\u56fd\u9999\u6e2f\u7279\u522b\u884c\u653f\u533a" },
             { "Vaii", "\u74e6\u4f9d\u6587" },
@@ -327,10 +327,12 @@ public class LocaleNames_zh extends OpenListResourceBundle {
             { "type.ca.islamic", "\u4f0a\u65af\u5170\u5386" },
             { "JM", "\u7259\u4e70\u52a0" },
             { "Beng", "\u5b5f\u52a0\u62c9\u6587" },
+            { "%%EKAVSK", "\u585e\u5c14\u7ef4\u4e9a\u8bed\u4f0a\u5361\u7ef4\u4e9a\u53d1\u97f3" },
             { "JO", "\u7ea6\u65e6" },
             { "JP", "\u65e5\u672c" },
             { "%%1606NICT", "1606 \u5e74\u524d\u4e2d\u540e\u671f\u6cd5\u6587" },
             { "ain", "\u963f\u4f0a\u52aa\u8bed" },
+            { "%%KOCIEWIE", "\u79d1\u5947\u97e6\u65b9\u8a00" },
             { "Mend", "\u95e8\u8fea\u6587" },
             { "guz", "\u53e4\u897f\u8bed" },
             { "tog", "\u5c3c\u4e9a\u8428\u6c64\u52a0\u8bed" },
@@ -385,6 +387,7 @@ public class LocaleNames_zh extends OpenListResourceBundle {
             { "vun", "\u6e29\u65e7\u8bed" },
             { "%%LAUKIKA", "\u4f20\u7edf\u68b5\u6587" },
             { "lah", "\u5370\u5ea6-\u96c5\u5229\u5b89\u8bed" },
+            { "Mahj", "\u9ed8\u54c8\u91d1\u6587" },
             { "lag", "\u6717\u5409\u8bed" },
             { "Thaa", "\u5854\u5b89\u90a3\u6587" },
             { "MA", "\u6469\u6d1b\u54e5" },
@@ -410,6 +413,7 @@ public class LocaleNames_zh extends OpenListResourceBundle {
             { "MQ", "\u9a6c\u63d0\u5c3c\u514b" },
             { "MR", "\u6bdb\u91cc\u5854\u5c3c\u4e9a" },
             { "MS", "\u8499\u7279\u585e\u62c9\u7279" },
+            { "Chrs", "\u82b1\u62c9\u5b50\u6a21\u6587" },
             { "MT", "\u9a6c\u8033\u4ed6" },
             { "type.m0.ungegn", "\u8054\u5408\u56fd\u5730\u540d\u4e13\u5bb6\u7ec4 (UNGEGN)" },
             { "MU", "\u6bdb\u91cc\u6c42\u65af" },
@@ -451,6 +455,7 @@ public class LocaleNames_zh extends OpenListResourceBundle {
             { "Mero", "\u9ea6\u82e5\u63d0\u514b\u6587" },
             { "crh", "\u514b\u91cc\u7c73\u4e9a\u571f\u8033\u5176\u8bed" },
             { "ang", "\u53e4\u82f1\u8bed" },
+            { "%%GRMISTR", "\u683c\u7c73\u65af\u7279\u65b9\u8a00" },
             { "OM", "\u963f\u66fc" },
             { "%%PETR1708", "\u4fc4\u6587\u62fc\u5b57\uff081708\u5e74\uff09" },
             { "anp", "\u6602\u52a0\u8bed" },
@@ -469,7 +474,7 @@ public class LocaleNames_zh extends OpenListResourceBundle {
             { "PK", "\u5df4\u57fa\u65af\u5766" },
             { "%%NICARD", "\u5c3c\u65af\u65b9\u8a00" },
             { "PL", "\u6ce2\u5170" },
-            { "ewo", "\u65fa\u675c\u8bed" },
+            { "ewo", "\u57c3\u7fc1\u591a\u8bed" },
             { "PM", "\u5723\u76ae\u57c3\u5c14\u548c\u5bc6\u514b\u9686\u7fa4\u5c9b" },
             { "PN", "\u76ae\u7279\u51ef\u6069\u7fa4\u5c9b" },
             { "PR", "\u6ce2\u591a\u9ece\u5404" },
@@ -502,6 +507,7 @@ public class LocaleNames_zh extends OpenListResourceBundle {
             { "jbo", "\u903b\u8f91\u8bed" },
             { "Rjng", "\u62c9\u8ba9\u6587" },
             { "009", "\u5927\u6d0b\u6d32" },
+            { "Elym", "\u57c3\u5229\u8fc8\u6587" },
             { "%%SURSILV", "\u745e\u58eb\u82cf\u745f\u74e6\u65b9\u8a00" },
             { "RO", "\u7f57\u9a6c\u5c3c\u4e9a" },
             { "RS", "\u585e\u5c14\u7ef4\u4e9a" },
@@ -509,6 +515,7 @@ public class LocaleNames_zh extends OpenListResourceBundle {
             { "RU", "\u4fc4\u7f57\u65af" },
             { "RW", "\u5362\u65fa\u8fbe" },
             { "type.nu.talu", "\u65b0\u50a3\u4ec2\u6587\u6570\u5b57" },
+            { "%%METELKO", "\u6885\u7279\u5c14\u79d1\u5b57\u6bcd" },
             { "Mani", "\u6469\u5c3c\u6559\u6587" },
             { "Ugar", "\u4e4c\u52a0\u91cc\u7279\u6587" },
             { "Khar", "\u5361\u7f57\u987b\u63d0\u6587" },
@@ -531,6 +538,7 @@ public class LocaleNames_zh extends OpenListResourceBundle {
             { "type.lb.strict", "\u4e25\u683c\u6362\u884c\u7b26\u6837\u5f0f" },
             { "017", "\u4e2d\u975e" },
             { "SI", "\u65af\u6d1b\u6587\u5c3c\u4e9a" },
+            { "type.nu.mymrtlng", "\u7f05\u7538\u6cf0\u5170\u6570\u5b57" },
             { "018", "\u5357\u90e8\u975e\u6d32" },
             { "SJ", "\u65af\u74e6\u5c14\u5df4\u548c\u626c\u9a6c\u5ef6" },
             { "019", "\u7f8e\u6d32" },
@@ -562,6 +570,7 @@ public class LocaleNames_zh extends OpenListResourceBundle {
             { "TC", "\u7279\u514b\u65af\u548c\u51ef\u79d1\u65af\u7fa4\u5c9b" },
             { "yav", "\u6d0b\u535e\u8bed" },
             { "TD", "\u4e4d\u5f97" },
+            { "Qaag", "Zawgyi" },
             { "TF", "\u6cd5\u5c5e\u5357\u90e8\u9886\u5730" },
             { "TG", "\u591a\u54e5" },
             { "TH", "\u6cf0\u56fd" },
@@ -604,6 +613,7 @@ public class LocaleNames_zh extends OpenListResourceBundle {
             { "US", "\u7f8e\u56fd" },
             { "haw", "\u590f\u5a01\u5937\u8bed" },
             { "%%1959ACAD", "\u5b66\u672f" },
+            { "%%IVANCHOV", "\u4f0a\u4e07\u4e54\u592b\u65b9\u8a00" },
             { "type.co.gb2312han", "\u7b80\u4f53\u4e2d\u6587\u6392\u5e8f - GB2312" },
             { "UY", "\u4e4c\u62c9\u572d" },
             { "prg", "\u666e\u9c81\u58eb\u8bed" },
@@ -614,6 +624,7 @@ public class LocaleNames_zh extends OpenListResourceBundle {
             { "VA", "\u68b5\u8482\u5188" },
             { "pro", "\u53e4\u666e\u7f57\u6587\u65af\u8bed" },
             { "VC", "\u5723\u6587\u68ee\u7279\u548c\u683c\u6797\u7eb3\u4e01\u65af" },
+            { "%%HSISTEMO", "\u8d6b\u897f\u65af\u7279\u83ab\u65b9\u8a00" },
             { "VE", "\u59d4\u5185\u745e\u62c9" },
             { "VG", "\u82f1\u5c5e\u7ef4\u5c14\u4eac\u7fa4\u5c9b" },
             { "VI", "\u7f8e\u5c5e\u7ef4\u5c14\u4eac\u7fa4\u5c9b" },
@@ -668,6 +679,7 @@ public class LocaleNames_zh extends OpenListResourceBundle {
             { "Sgnw", "\u4e66\u5199\u7b26\u53f7" },
             { "YT", "\u9a6c\u7ea6\u7279" },
             { "type.nu.cham", "\u5360\u6587\u6570\u5b57" },
+            { "%%NEWFOUND", "\u7ebd\u82ac\u5170\u65b9\u8a00" },
             { "ZA", "\u5357\u975e" },
             { "type.nu.sund", "\u82cf\u4e39\u6587\u6570\u5b57" },
             { "type.lb.loose", "\u5bbd\u677e\u6362\u884c\u7b26\u6837\u5f0f" },
@@ -687,8 +699,10 @@ public class LocaleNames_zh extends OpenListResourceBundle {
             { "type.nu.telu", "\u6cf0\u5362\u56fa\u6570\u5b57" },
             { "lou", "\u8def\u6613\u65af\u5b89\u90a3\u514b\u91cc\u5965\u5c14\u8bed" },
             { "loz", "\u6d1b\u9f50\u8bed" },
+            { "%%FONKIRSH", "\u4e30\u5409\u4ec0\u65b9\u8a00" },
             { "Nkgb", "\u7eb3\u897f\u683c\u5df4\u6587" },
             { "%%ASANTE", "\u963f\u6563\u8482\u65b9\u8a00" },
+            { "%%AUVERN", "\u81ea\u52a8\u94bb\u673a" },
             { "jmc", "\u9a6c\u5207\u59c6\u8bed" },
             { "type.nu.hansfin", "\u7b80\u4f53\u4e2d\u6587\u5927\u5199\u6570\u5b57" },
             { "hil", "\u5e0c\u5229\u76d6\u519c\u8bed" },
@@ -706,6 +720,7 @@ public class LocaleNames_zh extends OpenListResourceBundle {
             { "nwc", "\u53e4\u5178\u5c3c\u74e6\u5c14\u8bed" },
             { "udm", "\u4e4c\u5fb7\u7a46\u5c14\u7279\u8bed" },
             { "Khmr", "\u9ad8\u68c9\u6587" },
+            { "%%FONNAPA", "\u798f\u7eb3\u5e15\u65b9\u8a00" },
             { "type.ca.islamic-rgsa", "\u6c99\u7279\u963f\u62c9\u4f2f\u4f0a\u65af\u5170\u5386" },
             { "Limb", "\u6797\u5e03\u6587" },
             { "sad", "\u6851\u8fbe\u97e6\u8bed" },
@@ -713,6 +728,7 @@ public class LocaleNames_zh extends OpenListResourceBundle {
             { "sah", "\u8428\u54c8\u8bed" },
             { "type.nu.shrd", "\u590f\u62c9\u8fbe\u6570\u5b57" },
             { "sam", "\u8428\u9a6c\u5229\u4e9a\u963f\u62c9\u59c6\u8bed" },
+            { "Aghb", "\u9ad8\u52a0\u7d22\u963f\u5c14\u5df4\u5c3c\u4e9a\u6587" },
             { "%%SCOUSE", "\u5229\u7269\u6d66\u65b9\u8a00" },
             { "saq", "\u6851\u5e03\u9c81\u8bed" },
             { "sas", "\u8428\u8428\u514b\u6587" },
@@ -724,12 +740,14 @@ public class LocaleNames_zh extends OpenListResourceBundle {
             { "sba", "\u7518\u62dc\u8bed" },
             { "Guru", "\u679c\u9c81\u7a46\u5947\u6587" },
             { "%%ALUKU", "\u963f\u9c81\u5e93\u65b9\u8a00" },
+            { "type.nu.diak", "\u8fea\u7ef4\u897f\u963f\u5e93\u9c81\u6570\u5b57" },
             { "lua", "\u5362\u5df4-\u5362\u62c9\u8bed" },
             { "%%BISCAYAN", "\u6bd4\u65af\u5f00\u65b9\u8a00" },
             { "type.nu.tirh", "\u8fc8\u8482\u5229\u6570\u5b57" },
             { "type.d0.fwidth", "\u5168\u89d2" },
             { "sbp", "\u6851\u53e4\u8bed" },
             { "lui", "\u5362\u4f0a\u585e\u8bfa\u8bed" },
+            { "%%GRITAL", "\u683c\u91cc\u9676\u65b9\u8a00" },
             { "nyn", "\u5c3c\u6602\u79d1\u52d2\u8bed" },
             { "nym", "\u5c3c\u626c\u97e6\u9f50\u8bed" },
             { "lun", "\u9686\u8fbe\u8bed" },
@@ -755,6 +773,7 @@ public class LocaleNames_zh extends OpenListResourceBundle {
             { "scn", "\u897f\u897f\u91cc\u8bed" },
             { "aa", "\u963f\u6cd5\u5c14\u8bed" },
             { "ab", "\u963f\u5e03\u54c8\u897f\u4e9a\u8bed" },
+            { "Aran", "\u6ce2\u65af\u4f53" },
             { "ae", "\u963f\u7ef4\u65af\u5854\u8bed" },
             { "af", "\u5357\u975e\u8377\u5170\u8bed" },
             { "ak", "\u963f\u80af\u8bed" },
@@ -776,6 +795,7 @@ public class LocaleNames_zh extends OpenListResourceBundle {
             { "az", "\u963f\u585e\u62dc\u7586\u8bed" },
             { "Rohg", "\u54c8\u4e43\u6590\u7f57\u5174\u4e9a\u6587" },
             { "Khoj", "\u514b\u5409\u5947\u6587\u5b57" },
+            { "%%CISAUP", "\u897f\u8428\u666e\u65b9\u8a00" },
             { "%%OSOJS", "Oseacco/Osojane \u65b9\u8a00" },
             { "%%UNIFON", "Unifon\u97f3\u4f4d\u5b57\u6bcd" },
             { "ba", "\u5df4\u4ec0\u57fa\u5c14\u8bed" },
@@ -867,9 +887,11 @@ public class LocaleNames_zh extends OpenListResourceBundle {
             { "type.m0.bgn", "\u7f8e\u56fd\u5730\u540d\u59d4\u5458\u4f1a (BGN)" },
             { "umb", "\u7fc1\u672c\u675c\u8bed" },
             { "fr", "\u6cd5\u8bed" },
+            { "%%AKUAPEM", "\u963f\u5938\u4f69\u59c6\u65b9\u8a00" },
             { "sid", "\u6089\u8fbe\u6469\u8bed" },
             { "fy", "\u897f\u5f17\u91cc\u897f\u4e9a\u8bed" },
             { "ga", "\u7231\u5c14\u5170\u8bed" },
+            { "Wcho", "\u4e07\u79cb\u6587" },
             { "gd", "\u82cf\u683c\u5170\u76d6\u5c14\u8bed" },
             { "Gong", "\u8d21\u8d3e\u62c9\u8d21\u5fb7\u6587" },
             { "gl", "\u52a0\u5229\u897f\u4e9a\u8bed" },
@@ -960,7 +982,9 @@ public class LocaleNames_zh extends OpenListResourceBundle {
             { "kw", "\u5eb7\u6c83\u5c14\u8bed" },
             { "ky", "\u67ef\u5c14\u514b\u5b5c\u8bed" },
             { "snk", "\u7d22\u5b81\u514b\u8bed" },
+            { "Mult", "\u7a46\u5c14\u5766\u6587" },
             { "la", "\u62c9\u4e01\u8bed" },
+            { "Hatr", "\u54c8\u7279\u5170\u6587" },
             { "lb", "\u5362\u68ee\u5821\u8bed" },
             { "type.nu.mlym", "\u9a6c\u62c9\u96c5\u62c9\u59c6\u6570\u5b57" },
             { "lg", "\u5362\u5e72\u8fbe\u8bed" },
@@ -1004,6 +1028,7 @@ public class LocaleNames_zh extends OpenListResourceBundle {
             { "nl", "\u8377\u5170\u8bed" },
             { "nn", "\u632a\u5a01\u5c3c\u8bfa\u65af\u514b\u8bed" },
             { "no", "\u632a\u5a01\u8bed" },
+            { "%%PROVENC", "\u666e\u7f57\u65fa\u65af\u65b9\u8a00" },
             { "nr", "\u5357\u6069\u5fb7\u8d1d\u52d2\u8bed" },
             { "type.nu.modi", "\u83ab\u8fea\u6570\u5b57" },
             { "Osge", "\u6b27\u585e\u5947\u6587" },
@@ -1024,13 +1049,14 @@ public class LocaleNames_zh extends OpenListResourceBundle {
             { "om", "\u5965\u7f57\u83ab\u8bed" },
             { "kaw", "\u5361\u5a01\u8bed" },
             { "or", "\u5965\u91cc\u4e9a\u8bed" },
+            { "Modi", "\u83ab\u8fea\u6587" },
             { "os", "\u5965\u585e\u68af\u8bed" },
             { "%%ALALC97", "1997 \u7248 ALA-LC \u7f57\u9a6c\u5b57" },
             { "kbd", "\u5361\u5df4\u5c14\u5fb7\u8bed" },
             { "mfe", "\u6bdb\u91cc\u6c42\u65af\u514b\u91cc\u5965\u5c14\u8bed" },
             { "srn", "\u82cf\u91cc\u5357\u6c64\u52a0\u8bed" },
             { "pa", "\u65c1\u906e\u666e\u8bed" },
-            { "dua", "\u90fd\u963f\u62c9\u8bed" },
+            { "dua", "\u675c\u963f\u62c9\u8bed" },
             { "srr", "\u585e\u96f7\u5c14\u8bed" },
             { "%%LIPAW", "\u96f7\u897f\u4e9a Lipovaz \u65b9\u8a00" },
             { "kbl", "\u52a0\u6d85\u59c6\u5e03\u8bed" },
@@ -1045,6 +1071,7 @@ public class LocaleNames_zh extends OpenListResourceBundle {
             { "mga", "\u4e2d\u53e4\u7231\u5c14\u5170\u8bed" },
             { "key.co", "\u6392\u5e8f" },
             { "pt_BR", "\u5df4\u897f\u8461\u8404\u7259\u8bed" },
+            { "%%BOHORIC", "\u535a\u970d\u91cc\u5947\u5b57\u6bcd" },
             { "kcg", "\u5361\u5854\u5e03\u8bed" },
             { "mgh", "\u9a6c\u5e93\u963f\u8bed" },
             { "key.cf", "\u8d27\u5e01\u683c\u5f0f" },
@@ -1115,6 +1142,7 @@ public class LocaleNames_zh extends OpenListResourceBundle {
             { "%%NEDIS", "Natisone \u65b9\u8a00" },
             { "sv", "\u745e\u5178\u8bed" },
             { "sw", "\u65af\u74e6\u5e0c\u91cc\u8bed" },
+            { "type.nu.wcho", "\u4e07\u79cb\u6570\u5b57" },
             { "type.nu.hantfin", "\u7e41\u4f53\u4e2d\u6587\u5927\u5199\u6570\u5b57" },
             { "ibb", "\u4f0a\u6bd4\u6bd4\u5965\u8bed" },
             { "iba", "\u4f0a\u73ed\u8bed" },
@@ -1143,6 +1171,7 @@ public class LocaleNames_zh extends OpenListResourceBundle {
             { "swb", "\u79d1\u6469\u7f57\u8bed" },
             { "Cakm", "\u67e5\u514b\u9a6c\u6587" },
             { "tt", "\u9791\u977c\u8bed" },
+            { "%%XSISTEMO", "\u897f\u897f\u65af\u7279\u83ab\u65b9\u8a00" },
             { "dyu", "\u8fea\u5c24\u62c9\u8bed" },
             { "tw", "\u5951\u7ef4\u8bed" },
             { "ty", "\u5854\u5e0c\u63d0\u8bed" },
@@ -1260,6 +1289,7 @@ public class LocaleNames_zh extends OpenListResourceBundle {
             { "Tglg", "\u5854\u52a0\u8def\u6587" },
             { "Egyd", "\u540e\u671f\u57c3\u53ca\u6587" },
             { "Egyh", "\u53e4\u57c3\u53ca\u50e7\u4fa3\u4e66\u5199\u4f53" },
+            { "Yezi", "\u96c5\u5179\u8fea\u6587" },
             { "%%ITIHASA", "\u53f2\u8bd7\u68b5\u6587" },
             { "Palm", "\u5e15\u5c14\u8fc8\u62c9\u6587" },
             { "ebu", "\u6069\u5e03\u8bed" },
@@ -1279,14 +1309,18 @@ public class LocaleNames_zh extends OpenListResourceBundle {
             { "Sund", "\u5dfd\u4ed6\u6587" },
             { "vep", "\u7ef4\u666e\u68ee\u8bed" },
             { "kpe", "\u514b\u4f69\u5217\u8bed" },
+            { "%%GRCLASS", "\u7c97\u7c92\u7ea7" },
             { "type.nu.khmr", "\u9ad8\u68c9\u6570\u5b57" },
             { "Tirh", "\u8fc8\u8482\u5229\u6587" },
             { "ilo", "\u4f0a\u6d1b\u5361\u8bfa\u8bed" },
             { "%%VALENCIA", "\u74e6\u4f26\u897f\u4e9a\u6587" },
             { "Cprt", "\u585e\u6d66\u8def\u65af\u6587" },
+            { "Diak", "\u8fea\u7ef4\u897f\u963f\u5e93\u9c81\u6587" },
             { "%%BAKU1926", "\u7edf\u4e00\u571f\u8033\u5176\u62c9\u4e01\u5b57\u6bcd" },
+            { "%%IJEKAVSK", "\u585e\u5c14\u7ef4\u4e9a\u8bed\u4f0a\u5409\u5361\u7ef4\u4e9a\u53d1\u97f3" },
             { "mua", "\u8499\u5f53\u8bed" },
             { "type.nu.guru", "\u679c\u9c81\u7a46\u5947\u6570\u5b57" },
+            { "%%BORNHOLM", "\u535a\u6069\u970d\u5c14\u59c6\u65b9\u8a00" },
             { "mul", "\u591a\u8bed\u79cd" },
             { "%%PUTER", "\u745e\u58eb\u666e\u7279\u5c14\u65b9\u8a00" },
             { "cad", "\u5361\u591a\u8bed" },
@@ -1301,6 +1335,7 @@ public class LocaleNames_zh extends OpenListResourceBundle {
             { "type.nu.tamldec", "\u6cf0\u7c73\u5c14\u6570\u5b57" },
             { "krc", "\u5361\u62c9\u6070\u4f0a\u5df4\u5c14\u5361\u5c14\u8bed" },
             { "inh", "\u5370\u53e4\u4ec0\u8bed" },
+            { "fa_AF", "\u8fbe\u91cc\u8bed" },
             { "krl", "\u5361\u7d2f\u5229\u963f\u8bed" },
             { "%%OXENDICT", "\u300a\u725b\u6d25\u82f1\u8bed\u8bcd\u5178\u300b\u62fc\u6cd5" },
             { "efi", "\u57c3\u83f2\u514b\u8bed" },
